<?php
namespace MascotCoreKologiWP;

/**
 * Class Plugin
 *
 * Main Plugin class
 * @since 1.2.0
 */
class Plugin {

	/**
	 * Instance
	 *
	 * @since 1.2.0
	 * @access private
	 * @static
	 *
	 * @var Plugin The single instance of the class.
	 */
	private static $_instance = null;
	public $widgets = array();
	public $wpcf_status = array();
	public $give_status = false;
	public $events_status = false;
	public $woocommerce_status = false;

	/**
	 * Instance
	 *
	 * Ensures only one instance of the class is loaded or can be loaded.
	 *
	 * @since 1.2.0
	 * @access public
	 *
	 * @return Plugin An instance of the class.
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	/**
	 * widget_scripts
	 *
	 * Load required plugin core files.
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function widget_scripts() {
		wp_register_script( 'mascot-core-hellojs', plugins_url( '/assets/js/elementor-mascot.js', __FILE__ ), [ 'jquery' ], false, true );
	}

	public function widget_styles() {
		wp_enqueue_style( 'mascot-core-elementor-css', plugins_url( '/assets/css/elementor-mascot.css', __FILE__ ) );
	}

	public function give_status() {

		if ( class_exists( 'Give' ) ) {
			$this->give_status = true;
		}

		return $this->give_status;
	}

	public function wpcf_status() {

		if ( class_exists( 'WPCF\Crowdfunding' ) ) {
			$this->wpcf_status = true;
		}

		return $this->wpcf_status;
	}

	public function events_status() {

		if ( class_exists( 'Tribe__Events__Main' ) ) {
			$this->events_status = true;
		}

		return $this->events_status;
	}

	public function woocommerce_status() {

		if ( class_exists( 'WooCommerce' ) ) {
			$this->woocommerce_status = true;
		}

		return $this->woocommerce_status;
	}

	public function widgets_list() {
		$this->widgets = array(
			'blog-list',
			'block-features',
			'header-primary-nav',
			'header-nav-side-icons',
			'page-title',
			'site-logo'
		);

		// Give
		if ( $this->give_status() ) {
			//require_once( __DIR__ . '/widgets/gives-function.php' );
			$this->widgets = array_merge(
				$this->widgets, array(
					'give-forms',
					'give-donation-form',
				)
			);
		}

		// WP Crowdfunding
		if ( $this->wpcf_status() ) {
			//require_once( __DIR__ . '/widgets/gives-function.php' );
			$this->widgets = array_merge(
				$this->widgets, array(
					'wpcf-listing',
					'wpcf-category',
					'wpcf-donate-btn',
					'wpcf-creator',
					'wpcf-info',
					'wpcf-media',
					'wpcf-post-title',
					'wpcf-progress',
					'wpcf-short-story',
					'wpcf-tabs'
				)
			);
		}

		// Tribe Events.
		if ( $this->events_status() ) {
			//require_once( __DIR__ . '/widgets/events-function.php' );
			$this->widgets = array_merge(
				$this->widgets, array(
					'tribe-events',
				)
			);
		}
		return $this->widgets;
	}


	/**
	 * Include Widgets files
	 *
	 * Load widgets files
	 *
	 * @since 1.2.0
	 * @access private
	 */
	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/wpcf-base.php' );
		
		foreach( $this->widgets_list() as $widget ) {
			require_once( __DIR__ . '/widgets/'. $widget .'/widget.php' );

			foreach( glob( __DIR__ . '/widgets/'. $widget .'/skins/*.php') as $filepath ) {
				include $filepath;
			}
		}
	}
	private function include_widgets_files_cpt() {
		//cpt
		require_once( __DIR__ . '/cpt/projects/loader.php' );
		require_once( __DIR__ . '/cpt/services/widget.php' );
		require_once( __DIR__ . '/cpt/staff/widget.php' );
		require_once( __DIR__ . '/cpt/testimonials/widget.php' );
		require_once( __DIR__ . '/cpt/blog/widget.php' );

		$cpt_list = array(
			'projects',
			'services',
			'staff',
			'testimonials',
			'blog',
		);

		foreach( $cpt_list as $cpt ) {
			foreach( glob( __DIR__ . '/cpt/'. $cpt .'/skins/*.php') as $filepath ) {
				include $filepath;
			}
		}
	}
	private function include_widgets_files_current_theme() {
	}
	
	private function include_widgets_files_shop() {
		//shop
		require_once( __DIR__ . '/widgets-shop/info-banner/widget.php' );
		require_once( __DIR__ . '/widgets-shop/wc-products/widget.php' );
	}

	/**
	 * Register Widgets
	 *
	 * Register new Elementor widgets.
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files();
		$this->include_widgets_files_cpt();
		$this->include_widgets_files_current_theme();

		// WooCommerce.
		if ( $this->woocommerce_status() ) {
			$this->include_widgets_files_shop();
		}

		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\TM_Elementor_Blog_List() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\TM_Elementor_BlockFeatures() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\TM_Elementor_Page_Title() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\TM_Elementor_Site_Logo() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\TM_Elementor_Top_Primary_Nav() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Header_Nav_Side_Icons\TM_Elementor_Header_Nav_Side_Icons() );

		//cpt
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Projects\TM_Elementor_Projects() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Services\TM_Elementor_Services() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Staff\TM_Elementor_Staff() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Testimonials\TM_Elementor_Testimonials() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Blog\TM_Elementor_Blog() );

		//Give Campaign
		if ( $this->give_status() ) {
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\GiveForms\TM_Elementor_Give_Forms() );
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\GiveSingleForm\TM_Elementor_Give_Single_Form() );
		}

		if ( $this->events_status() ) {
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Events\TM_Elementor_Tribe_Events() );
		}

		//Shop Widgets
		if ( $this->woocommerce_status() ) {
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\TM_Elementor_WP_Products() );
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\TM_Elementor_InfoBanner() );
		}

		//Give Campaign
		if ( $this->wpcf_status() ) {
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\WPCF\TM_Elementor_WPCF_Listing() );
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\WPCF\TM_Elementor_WPCF_Category() );
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\WPCF\TM_Elementor_WPCF_Creator() );
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\WPCF\TM_Elementor_WPCF_Donate_Button() );
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\WPCF\TM_Elementor_WPCF_Item_Info() );
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\WPCF\TM_Elementor_WPCF_Media() );
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\WPCF\TM_Elementor_WPCF_Post_Title() );
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\WPCF\TM_Elementor_WPCF_Progress_Bar() );
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\WPCF\TM_Elementor_WPCF_Short_Story() );
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\WPCF\TM_Elementor_WPCF_Tabs() );
		}
	}

	/**
	 *  Plugin class constructor
	 *
	 * Register plugin action hooks and filters
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function __construct() {

		// Register widget scripts
		add_action( 'elementor/frontend/before_register_scripts', [ $this, 'widget_scripts' ] );
		add_action( 'elementor/editor/before_enqueue_scripts', [ $this, 'widget_styles' ] );

		// Register widgets
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'register_widgets' ] );
	}
}

// Instantiate Plugin Class
Plugin::instance();
